ItemVariationStore

Struct ItemVariationStore 

pub struct ItemVariationStore<'a> {
    data: FontData<'a>,
}
Fields

data: FontData<'a>

Implementations

Source

impl<'a> ItemVariationStore<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn format(&self) -> u16

Format— set to 1

pub fn variation_region_list_offset(&self) -> Offset32

Offset in bytes from the start of the item variation store to the variation region list.

pub fn variation_region_list( &self, ) -> Result<VariationRegionList<'a>, ReadError>

Attempt to resolve variation_region_list_offset.

pub fn item_variation_data_count(&self) -> u16

The number of item variation data subtables.

pub fn item_variation_data_offsets(&self) -> &'a [BigEndian<Nullable<Offset32>>]

Offsets in bytes from the start of the item variation store to each item variation data subtable.

pub fn item_variation_data( &self, ) -> ArrayOfNullableOffsets<'a, ItemVariationData<'a>, Offset32>

A dynamically resolving wrapper for item_variation_data_offsets.

pub fn format_byte_range(&self) -> Range<usize>

pub fn variation_region_list_offset_byte_range(&self) -> Range<usize>

pub fn item_variation_data_count_byte_range(&self) -> Range<usize>

pub fn item_variation_data_offsets_byte_range(&self) -> Range<usize>

Source

impl ItemVariationStore<'_>

pub fn compute_delta( &self, index: DeltaSetIndex, coords: &[F2Dot14], ) -> Result<i32, ReadError>

Computes the delta value for the specified index and set of normalized variation coordinates.

pub fn compute_float_delta( &self, index: DeltaSetIndex, coords: &[F2Dot14], ) -> Result<FloatItemDelta, ReadError>

Computes the delta value in floating point for the specified index and set of normalized variation coordinates.